/**
 * Azerbaijani translation for bootstrap-datetimepicker
 * Konstantin Kaluzhnikov <k.kaluzhnikov@gmail.com>
 */
;(function($){
	$.fn.datetimepicker.dates['az'] = {
		days: ["Bazar", "Bazar ertəsi", "Çərşənbə axşamı", "Çərşənbə", "Cümə axşamı", "Cümə", "Şənbə", "Bazar"],
		daysShort: ["B", "Be", "Ça", "Ç", "Ca", "C", "Ş", "B"],
		daysMin: ["B", "Be", "Ça", "Ç", "Ca", "C", "Ş", "B"],
		months: ["Yanvar", "Fevral", "Mart", "Aprel", "May", "İyun", "İyul", "Avqust", "Sentyabr", "Oktyabr", "Noyabr", "Dekabr"],
		monthsShort: ["Yan", "Fev", "Mar", "Apr", "May", "İyun", "İyul", "Avq", "Sen", "Okt", "Noy", "Dek"],
		today: "Bugün",
		suffix: [],
		meridiem: []
	};
}(jQuery));
