/**
 * Bangla(Bangladesh) translation for bootstrap-datetimepicker
 * Mahbub Rabbani <mahbub [dot] rucse [at] gmail.com>
 */
;(function($){
	$.fn.datetimepicker.dates['bn'] = {
		days: ["রবিবার", "সোমবার", "মঙ্গলবার", "বুধবার", "বৃহষ্পতিবার", "শুক্রবার", "শনিবার", "রবিবার"],
		daysShort: ["রবি", "সোম", "মঙ্গল", "বুধ", "  বৃহঃ", "শুক্র", "শনি", "রবি"],
		daysMin: ["রবি", "সোম", "মঙ্গ", "বুধ", "বৃহ", "শুক্র", "শনি", "রবি"],
		months: ['জানুয়ারী', 'ফেব্রুয়ারী', 'মার্চ', 'এপ্রিল', 'মে', 'জুন', 'জুলাই', 'অগাস্ট', 'সেপ্টেম্বর', 'অক্টোবর', 'নভেম্বর', 'ডিসেম্বর' ],
		monthsShort: ['জানু', 'ফেব্রু', 'মার্চ', 'এপ্রি', 'মে', 'জুন', 'জুলা', 'অগা', 'সেপ্টে', 'অক্টো', 'নভে', 'ডিসে' ],
		today: "আজ",
		suffix: [],
		meridiem: ['পূর্বাহ্ণ', 'অপরাহ্ন']
	};
}(jQuery));