{% load adminlte_helpers %}
<!-- Left side column. contains the sidebar -->
<aside class="main-sidebar">
    <!-- sidebar: style can be found in sidebar.less -->
    <section class="sidebar">
        <!-- Sidebar user panel -->
        {% block user_panel %}
        <div class="user-panel">
            <div class="pull-left image">
                <img src="{% avatar_url size=90 %}" class="img-circle" alt="User Image">
            </div>
            <div class="pull-left info">
                <p>{{ current_user.nickname }}</p>
                <a href="#"><i class="fa fa-circle text-success"></i> Online</a>
            </div>
        </div>
        {% endblock %}
        <!-- sidebar menu: : style can be found in sidebar.less -->
        {% block nav_links_ul %}
        <ul class="sidebar-menu">
            {% block nav_links_outer %}
            <li class="header">{% block nav_heading %}MAIN NAVIGATION{% endblock %}</li>

            {% block nav_links %}
                <li>
                    <a href="#">
                        <i class="fa fa-dashboard"></i> <span>Example link</span>
                    </a>
                </li>
                <li class="treeview">
                    <a href="#">
                        <i class="fa fa-group"></i> <span>Sub menu</span>
                        <span class="pull-right-container">
                            <i class="fa fa-angle-left pull-right"></i>
                        </span>
                    </a>
                    <ul class="treeview-menu">
                        <li>
                            <a href="#">
                                <i class="fa fa-user"></i> Another link
                            </a>
                        </li>
                    </ul>
                </li>
            {% endblock nav_links %}
            {% endblock nav_links_outer %}
        </ul>
        {% endblock nav_links_ul %}
    </section>
    <!-- /.sidebar -->
</aside>
