<script>
$(function () {
    $(".colorpicker").colorpicker();
});
</script>
<div class="input-group colorpicker colorpicker-element">
    <input type="text" class="{{ class }}" name="{{ name }}" id="{{ id }}" value="{{ value }}" />
    <div class="input-group-addon">
        <i></i>
    </div>
</div>