{% load static %}

{% block styles %}
<link rel="stylesheet" type="text/css"
      href="{% block stylesheet %}{% static "admin/css/base.css" %}{% endblock %}"/>
<link rel="stylesheet" type="text/css" href="{% static "bootstrap/dist/css/bootstrap.min.css" %}">
<!-- Font Awesome -->
<link rel="stylesheet" href="{% static 'font-awesome/css/font-awesome.min.css' %}">
<!-- Ionicons -->
<link rel="stylesheet" type="text/css" href="{% static "admin-lte/dist/css/AdminLTE.css" %}">
<link rel="stylesheet" type="text/css" href="{% static "admin-lte/dist/css/skins/_all-skins.min.css" %}">
<link rel="stylesheet" type="text/css" href="{% static "icheck/skins/minimal/blue.css" %}">
<link rel="stylesheet" type="text/css" href="{% static "conflicts/conflicts.css" %}">
<link rel="stylesheet" type="text/css" href="{% static '/datepicker/datepicker3.css' %}">
<link rel="stylesheet" type="text/css" href="{% static '/colorpicker/bootstrap-colorpicker.min.css' %}">
<link rel="stylesheet" type="text/css" href="{% static '/timepicker/bootstrap-timepicker.min.css' %}">
<link rel="stylesheet" type="text/css" href="{% static '/datetimepicker/css/bootstrap-datetimepicker.min.css' %}">
<link rel="stylesheet" type="text/css" href="{% static "select2/css/select2.min.css" %}">
<link rel="stylesheet" type="text/css" href="{% static "css/cruds.css" %}">
{% endblock %}
