<script>
$(function () {
    $(".timepickerwidget").timepicker({
          showInputs: false });
});
</script>

<div class="bootstrap-timepicker">
    <div class="input-group">
        <div class="input-group-addon">
            <i class="fa {% if icon %}{{ icon }}{% else %}fa-clock-o{% endif %}"></i>
            
        </div>
       
        <input type="text" class="{{ class }}" name="{{ name }}" format="{{format}}"
        id="{{ id }}" value="{{ value|date:djformat }}">
    </div>
</div>