{% load i18n %}
{% load crud_tags %}


<!-- Modal -->
<div class="modal-header">
    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
    <h4 class="modal-title" id="myModalLabel">{% trans "New" %} {{ model_verbose_name }}</h4>
</div>

<div class="modal-body">
    {% include "cruds/ajax/_form.html" with action='create' %}
</div>

<div class="modal-footer">
</div>

