{% if messages %}
    <div class="box">
        <div class="box-body">
            {% for message in messages %}
                {% if message.level == DEFAULT_MESSAGE_LEVELS.SUCCESS %}
                <div class="alert alert-success alert-dismissible">
                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
                    {{ message }}
                </div>
                {% elif message.level == DEFAULT_MESSAGE_LEVELS.ERROR %}
                <div class="alert alert-danger alert-dismissible">
                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
                    {{ message }}
                </div>
                {% else %}
                <div class="alert alert-info alert-dismissible">
                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
                    {{ message }}
                </div>
                {% endif %}
            {% endfor %}
        </div>
    </div>
{% endif %}
