{% extends "adminlte/base.html" %}

{% block body_class %}login-page{% endblock %}

{% block body %}
    <div class="login-box">
        {% block logo %}
        <div class="login-logo">
            {# Mirrors block names used in _main_header.html #}
            <a href="{% block logo_href %}/{% endblock %}">{% block logo_text %}<b>Admin</b>LTE{% endblock %}</a>
        </div>
        {% endblock %}
        <!-- /.login-logo -->
        <div class="login-box-body">
            {% block login_form %}
                <form action="" method="post">{% csrf_token %}
                    {% if message %}
                        <p class="login-box-msg" style="color: red;">{{ message }}</p>
                    {% endif %}
                    <div class="form-group has-feedback">
                        <input name="username" class="form-control" placeholder="Email">
                        <span class="glyphicon glyphicon-user form-control-feedback"></span>
                    </div>
                    <div class="form-group has-feedback">
                        <input type="password" name="password" class="form-control" placeholder="Password">
                        <span class="glyphicon glyphicon-lock form-control-feedback"></span>
                    </div>
                    <div class="row">
                        <div class="col-xs-8">
                        </div>
                        <div class="col-xs-4">
                            <button type="submit" class="btn btn-primary btn-block btn-flat">Login</button>
                        </div>
                    </div>
                </form>
            {% endblock login_form %}

        </div>
    </div>
{% endblock %}
